* [Home](https://help.sap.com/docs/)


# SAP LeanIX
English
SAP LeanIX enables you to efficiently manage, optimize, and scale your organization's enterprise architecture.
Provide feedback on our search

Search Scope
More
Favorite
Share
###  What's New
  * [Product Updates (Information published on non-SAP site)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fupdates.leanix.net%2F)
Explore our latest product releases and announcements.


###  Feature Scope Description
  * [Feature Scope Description (Information published on non-SAP site)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Flegal%2Fcommercial)
Understand which features are provided with SAP LeanIX.


###  Getting Started
  * [Getting Started Guide](https://help.sap.com/docs/LEANIX/72d375467c1e4dcb872dfa2998b6328d/275e1f657a4410149827eddaad3fba2e.html?locale=en-US&state=PRODUCTION&version=CLOUD)
Learn the essentials to embark on your journey with SAP LeanIX.


###  End-User Information
  * [Meta Model](https://help.sap.com/docs/LEANIX/72d375467c1e4dcb872dfa2998b6328d/275b21077a441014b2f6f94e10cfe6d3.html?locale=en-US&state=PRODUCTION&version=CLOUD)
Get an overview of the SAP LeanIX meta model and its key concepts.
  * [Use Cases](https://help.sap.com/docs/LEANIX/72d375467c1e4dcb872dfa2998b6328d/5e9774e0c5ee4594b41f27a3b15f713f.html?locale=en-US&state=PRODUCTION&version=CLOUD)
Discover practical scenarios with SAP LeanIX, such as application portfolio assessment and others.
  * [User Guide](https://help.sap.com/docs/LEANIX/72d375467c1e4dcb872dfa2998b6328d/275de8347a441014a630ae39f7e4df4e.html?locale=en-US&state=PRODUCTION&version=CLOUD)
Explore the key features of SAP LeanIX: inventory, reports, diagrams, and more.


###  Administration
  * [Administrator Guide](https://help.sap.com/docs/LEANIX/72d375467c1e4dcb872dfa2998b6328d/27586e417a441014a9be8eb259c326e1.html?locale=en-US&state=PRODUCTION&version=CLOUD)
Configure basic and advanced settings for your workspace.
  * [User and Access Management](https://help.sap.com/docs/LEANIX/72d375467c1e4dcb872dfa2998b6328d/4acb410e388a4692b29d72c983093ba8.html?locale=en-US&state=PRODUCTION&version=CLOUD)
Manage users and access permissions for your workspace.


###  Integration
  * [Discovery and Integrations](https://help.sap.com/docs/LEANIX/72d375467c1e4dcb872dfa2998b6328d/275ba7437a441014af4ea67e4bf11105.html?locale=en-US&state=PRODUCTION&version=CLOUD)
Set up discovery solutions and configure out-of-the-box integrations with external systems.
  * [Reference Catalog](https://help.sap.com/docs/LEANIX/72d375467c1e4dcb872dfa2998b6328d/275c0c797a441014a40ca4f67a09ca64.html?locale=en-US&state=PRODUCTION&version=CLOUD)
Use reference data to set up your inventory.


###  Additional Products
  * [SAP LeanIX Technology Risk and Compliance](https://help.sap.com/docs/LEANIX/72d375467c1e4dcb872dfa2998b6328d/2759c16d7a441014bfbcb629e2640027.html?locale=en-US&state=PRODUCTION&version=CLOUD)
Identify, assess, and mitigate technology risks to comply with regulations and standards.
  * [SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/LEANIX/72d375467c1e4dcb872dfa2998b6328d/2758bc147a441014b210c1a6641458da.html?locale=en-US&state=PRODUCTION&version=CLOUD)
Define the to-be state of your enterprise architecture and create actionable roadmaps.


###  Development
  * [Developer Guide](https://help.sap.com/docs/LEANIX/72d375467c1e4dcb872dfa2998b6328d/275e1bc77a441014b8ad99ed2759cee3.html?locale=en-US&state=PRODUCTION&version=CLOUD)
Discover available APIs and explore other resources for developers.


Back to top
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
